@@ -7,12 +7,12 @@
 
 extern SEXP RogueNaRok(SEXP, SEXP, SEXP, SEXP, SEXP,
                        SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP COPHENETIC(SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP COPHENETIC_LOG(SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP GRAPH_GEODESIC(SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP LOG_GRAPH_GEODESIC(SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef callMethods[] = {
-  {"COPHENETIC", (DL_FUNC) &COPHENETIC, 5},
-  {"COPHENETIC_LOG", (DL_FUNC) &COPHENETIC_LOG, 5},
+  {"GRAPH_GEODESIC", (DL_FUNC) &GRAPH_GEODESIC, 5},
+  {"LOG_GRAPH_GEODESIC", (DL_FUNC) &LOG_GRAPH_GEODESIC, 5},
   {"RogueNaRok", (DL_FUNC) &RogueNaRok, 10},
   {NULL, NULL, 0}
 };
